# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/study/v1/study.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/study/v1/study.proto',
  package='github.com.metaprov.modelaapi.services.study.v1',
  syntax='proto3',
  serialized_options=b'Z/github.com/metaprov/modelaapi/services/study/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;github.com/metaprov/modelaapi/services/study/v1/study.proto\x12/github.com.metaprov.modelaapi.services.study.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"2\n\x0fGetStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x10GetStudyResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"\xb3\x01\n\x10ListStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12]\n\x06labels\x18\x03 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x11ListStudyResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyList\"c\n\x12\x43reateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x15\n\x13\x43reateStudyResponse\"c\n\x12UpdateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x8d\x01\n\x19\x43reateStudyProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12O\n\x06models\x18\x03 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"J\n\x1a\x43reateStudyProfileResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"I\n\x16GetStudyProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06models\x18\x03 \x01(\x05\"\xc1\x01\n\x17GetStudyProfileResponse\x12O\n\x07profile\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.StudyProfile\x12U\n\rmodelsProfile\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"4\n\x11\x41\x62ortStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x41\x62ortStudyResponse\"4\n\x11PauseStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12PauseStudyResponse\"5\n\x12ResumeStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13ResumeStudyResponse\"5\n\x12\x44\x65leteStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteStudyResponse\"\x15\n\x13UpdateStudyResponse2\xc7\x10\n\x0cStudyService\x12\xa9\x01\n\x0bListStudies\x12\x41.github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest\x1a\x42.github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/studies\x12\xb0\x01\n\x0b\x43reateStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.CreateStudyResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/studies:\x01*\x12\xab\x01\n\x08GetStudy\x12@.github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest\x1a\x41.github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/studies/{name}\x12\xe1\x01\n\x0bUpdateStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.UpdateStudyResponse\"G\x82\xd3\xe4\x93\x02\x41\x1a</v1/studies/{study.metadata.namespace}/{study.metadata.name}:\x01*\x12\xc0\x01\n\x0b\x44\x65leteStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.DeleteStudyResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/studies/{namespace}/{name}\x12\xfb\x01\n\x12\x43reateStudyProfile\x12J.github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest\x1aK.github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse\"L\x82\xd3\xe4\x93\x02\x46\"D/v1/studies/{study.metadata.namespace}/{study.metadata.name}/profile\x12\xd4\x01\n\x0fGetStudyProfile\x12G.github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest\x1aH.github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/studies/{namespace}/{name}/profile\x12\xe1\x01\n\nAbortStudy\x12\x42.github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest\x1a\x43.github.com.metaprov.modelaapi.services.study.v1.AbortStudyResponse\"J\x82\xd3\xe4\x93\x02\x44\"B/v1/studies/{study.metadata.namespace}/{study.metadata.name}/abort\x12\xe1\x01\n\nPauseStudy\x12\x42.github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest\x1a\x43.github.com.metaprov.modelaapi.services.study.v1.PauseStudyResponse\"J\x82\xd3\xe4\x93\x02\x44\"B/v1/studies/{study.metadata.namespace}/{study.metadata.name}/pause\x12\xe5\x01\n\x0bResumeStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.ResumeStudyResponse\"K\x82\xd3\xe4\x93\x02\x45\"C/v1/studies/{study.metadata.namespace}/{study.metadata.name}/resumeB1Z/github.com/metaprov/modelaapi/services/study/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_GETSTUDYREQUEST = _descriptor.Descriptor(
  name='GetStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=329,
)


_GETSTUDYRESPONSE = _descriptor.Descriptor(
  name='GetStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=442,
)


_LISTSTUDYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=624,
)

_LISTSTUDYREQUEST = _descriptor.Descriptor(
  name='ListStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSTUDYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=624,
)


_LISTSTUDYRESPONSE = _descriptor.Descriptor(
  name='ListStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=729,
)


_CREATESTUDYREQUEST = _descriptor.Descriptor(
  name='CreateStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=830,
)


_CREATESTUDYRESPONSE = _descriptor.Descriptor(
  name='CreateStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=832,
  serialized_end=853,
)


_UPDATESTUDYREQUEST = _descriptor.Descriptor(
  name='UpdateStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=954,
)


_CREATESTUDYPROFILEREQUEST = _descriptor.Descriptor(
  name='CreateStudyProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest.models', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1098,
)


_CREATESTUDYPROFILERESPONSE = _descriptor.Descriptor(
  name='CreateStudyProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1100,
  serialized_end=1174,
)


_GETSTUDYPROFILEREQUEST = _descriptor.Descriptor(
  name='GetStudyProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest.models', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1249,
)


_GETSTUDYPROFILERESPONSE = _descriptor.Descriptor(
  name='GetStudyProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse.profile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelsProfile', full_name='github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse.modelsProfile', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1445,
)


_ABORTSTUDYREQUEST = _descriptor.Descriptor(
  name='AbortStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1499,
)


_ABORTSTUDYRESPONSE = _descriptor.Descriptor(
  name='AbortStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.AbortStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1521,
)


_PAUSESTUDYREQUEST = _descriptor.Descriptor(
  name='PauseStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1575,
)


_PAUSESTUDYRESPONSE = _descriptor.Descriptor(
  name='PauseStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.PauseStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1577,
  serialized_end=1597,
)


_RESUMESTUDYREQUEST = _descriptor.Descriptor(
  name='ResumeStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1599,
  serialized_end=1652,
)


_RESUMESTUDYRESPONSE = _descriptor.Descriptor(
  name='ResumeStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.ResumeStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1675,
)


_DELETESTUDYREQUEST = _descriptor.Descriptor(
  name='DeleteStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1730,
)


_DELETESTUDYRESPONSE = _descriptor.Descriptor(
  name='DeleteStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.DeleteStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1753,
)


_UPDATESTUDYRESPONSE = _descriptor.Descriptor(
  name='UpdateStudyResponse',
  full_name='github.com.metaprov.modelaapi.services.study.v1.UpdateStudyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1776,
)

_GETSTUDYRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_LISTSTUDYREQUEST_LABELSENTRY.containing_type = _LISTSTUDYREQUEST
_LISTSTUDYREQUEST.fields_by_name['labels'].message_type = _LISTSTUDYREQUEST_LABELSENTRY
_LISTSTUDYRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDYLIST
_CREATESTUDYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_UPDATESTUDYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_CREATESTUDYPROFILEREQUEST.fields_by_name['models'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_GETSTUDYPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._STUDYPROFILE
_GETSTUDYPROFILERESPONSE.fields_by_name['modelsProfile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._MODELPROFILE
DESCRIPTOR.message_types_by_name['GetStudyRequest'] = _GETSTUDYREQUEST
DESCRIPTOR.message_types_by_name['GetStudyResponse'] = _GETSTUDYRESPONSE
DESCRIPTOR.message_types_by_name['ListStudyRequest'] = _LISTSTUDYREQUEST
DESCRIPTOR.message_types_by_name['ListStudyResponse'] = _LISTSTUDYRESPONSE
DESCRIPTOR.message_types_by_name['CreateStudyRequest'] = _CREATESTUDYREQUEST
DESCRIPTOR.message_types_by_name['CreateStudyResponse'] = _CREATESTUDYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateStudyRequest'] = _UPDATESTUDYREQUEST
DESCRIPTOR.message_types_by_name['CreateStudyProfileRequest'] = _CREATESTUDYPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CreateStudyProfileResponse'] = _CREATESTUDYPROFILERESPONSE
DESCRIPTOR.message_types_by_name['GetStudyProfileRequest'] = _GETSTUDYPROFILEREQUEST
DESCRIPTOR.message_types_by_name['GetStudyProfileResponse'] = _GETSTUDYPROFILERESPONSE
DESCRIPTOR.message_types_by_name['AbortStudyRequest'] = _ABORTSTUDYREQUEST
DESCRIPTOR.message_types_by_name['AbortStudyResponse'] = _ABORTSTUDYRESPONSE
DESCRIPTOR.message_types_by_name['PauseStudyRequest'] = _PAUSESTUDYREQUEST
DESCRIPTOR.message_types_by_name['PauseStudyResponse'] = _PAUSESTUDYRESPONSE
DESCRIPTOR.message_types_by_name['ResumeStudyRequest'] = _RESUMESTUDYREQUEST
DESCRIPTOR.message_types_by_name['ResumeStudyResponse'] = _RESUMESTUDYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteStudyRequest'] = _DELETESTUDYREQUEST
DESCRIPTOR.message_types_by_name['DeleteStudyResponse'] = _DELETESTUDYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateStudyResponse'] = _UPDATESTUDYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStudyRequest = _reflection.GeneratedProtocolMessageType('GetStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest)
  })
_sym_db.RegisterMessage(GetStudyRequest)

GetStudyResponse = _reflection.GeneratedProtocolMessageType('GetStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse)
  })
_sym_db.RegisterMessage(GetStudyResponse)

ListStudyRequest = _reflection.GeneratedProtocolMessageType('ListStudyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSTUDYREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest)
  })
_sym_db.RegisterMessage(ListStudyRequest)
_sym_db.RegisterMessage(ListStudyRequest.LabelsEntry)

ListStudyResponse = _reflection.GeneratedProtocolMessageType('ListStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse)
  })
_sym_db.RegisterMessage(ListStudyResponse)

CreateStudyRequest = _reflection.GeneratedProtocolMessageType('CreateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest)
  })
_sym_db.RegisterMessage(CreateStudyRequest)

CreateStudyResponse = _reflection.GeneratedProtocolMessageType('CreateStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyResponse)
  })
_sym_db.RegisterMessage(CreateStudyResponse)

UpdateStudyRequest = _reflection.GeneratedProtocolMessageType('UpdateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest)
  })
_sym_db.RegisterMessage(UpdateStudyRequest)

CreateStudyProfileRequest = _reflection.GeneratedProtocolMessageType('CreateStudyProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest)
  })
_sym_db.RegisterMessage(CreateStudyProfileRequest)

CreateStudyProfileResponse = _reflection.GeneratedProtocolMessageType('CreateStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse)
  })
_sym_db.RegisterMessage(CreateStudyProfileResponse)

GetStudyProfileRequest = _reflection.GeneratedProtocolMessageType('GetStudyProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest)
  })
_sym_db.RegisterMessage(GetStudyProfileRequest)

GetStudyProfileResponse = _reflection.GeneratedProtocolMessageType('GetStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse)
  })
_sym_db.RegisterMessage(GetStudyProfileResponse)

AbortStudyRequest = _reflection.GeneratedProtocolMessageType('AbortStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest)
  })
_sym_db.RegisterMessage(AbortStudyRequest)

AbortStudyResponse = _reflection.GeneratedProtocolMessageType('AbortStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.AbortStudyResponse)
  })
_sym_db.RegisterMessage(AbortStudyResponse)

PauseStudyRequest = _reflection.GeneratedProtocolMessageType('PauseStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest)
  })
_sym_db.RegisterMessage(PauseStudyRequest)

PauseStudyResponse = _reflection.GeneratedProtocolMessageType('PauseStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.PauseStudyResponse)
  })
_sym_db.RegisterMessage(PauseStudyResponse)

ResumeStudyRequest = _reflection.GeneratedProtocolMessageType('ResumeStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest)
  })
_sym_db.RegisterMessage(ResumeStudyRequest)

ResumeStudyResponse = _reflection.GeneratedProtocolMessageType('ResumeStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ResumeStudyResponse)
  })
_sym_db.RegisterMessage(ResumeStudyResponse)

DeleteStudyRequest = _reflection.GeneratedProtocolMessageType('DeleteStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest)
  })
_sym_db.RegisterMessage(DeleteStudyRequest)

DeleteStudyResponse = _reflection.GeneratedProtocolMessageType('DeleteStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteStudyResponse)
  })
_sym_db.RegisterMessage(DeleteStudyResponse)

UpdateStudyResponse = _reflection.GeneratedProtocolMessageType('UpdateStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateStudyResponse)
  })
_sym_db.RegisterMessage(UpdateStudyResponse)


DESCRIPTOR._options = None
_LISTSTUDYREQUEST_LABELSENTRY._options = None

_STUDYSERVICE = _descriptor.ServiceDescriptor(
  name='StudyService',
  full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1779,
  serialized_end=3898,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListStudies',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.ListStudies',
    index=0,
    containing_service=None,
    input_type=_LISTSTUDYREQUEST,
    output_type=_LISTSTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002\r\022\013/v1/studies',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.CreateStudy',
    index=1,
    containing_service=None,
    input_type=_CREATESTUDYREQUEST,
    output_type=_CREATESTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/studies:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.GetStudy',
    index=2,
    containing_service=None,
    input_type=_GETSTUDYREQUEST,
    output_type=_GETSTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/studies/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.UpdateStudy',
    index=3,
    containing_service=None,
    input_type=_UPDATESTUDYREQUEST,
    output_type=_UPDATESTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002A\032</v1/studies/{study.metadata.namespace}/{study.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.DeleteStudy',
    index=4,
    containing_service=None,
    input_type=_DELETESTUDYREQUEST,
    output_type=_DELETESTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002 *\036/v1/studies/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStudyProfile',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.CreateStudyProfile',
    index=5,
    containing_service=None,
    input_type=_CREATESTUDYPROFILEREQUEST,
    output_type=_CREATESTUDYPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002F\"D/v1/studies/{study.metadata.namespace}/{study.metadata.name}/profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStudyProfile',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.GetStudyProfile',
    index=6,
    containing_service=None,
    input_type=_GETSTUDYPROFILEREQUEST,
    output_type=_GETSTUDYPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/v1/studies/{namespace}/{name}/profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.AbortStudy',
    index=7,
    containing_service=None,
    input_type=_ABORTSTUDYREQUEST,
    output_type=_ABORTSTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002D\"B/v1/studies/{study.metadata.namespace}/{study.metadata.name}/abort',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.PauseStudy',
    index=8,
    containing_service=None,
    input_type=_PAUSESTUDYREQUEST,
    output_type=_PAUSESTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002D\"B/v1/studies/{study.metadata.namespace}/{study.metadata.name}/pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeStudy',
    full_name='github.com.metaprov.modelaapi.services.study.v1.StudyService.ResumeStudy',
    index=9,
    containing_service=None,
    input_type=_RESUMESTUDYREQUEST,
    output_type=_RESUMESTUDYRESPONSE,
    serialized_options=b'\202\323\344\223\002E\"C/v1/studies/{study.metadata.namespace}/{study.metadata.name}/resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STUDYSERVICE)

DESCRIPTOR.services_by_name['StudyService'] = _STUDYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto',
  package='github.com.metaprov.modelaapi.services.notebookrun.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/notebookrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGgithub.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto\x12\x35github.com.metaprov.modelaapi.services.notebookrun.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xc7\x01\n\x17ListNotebookRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x18ListNotebookRunsResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunList\"\x15\n\x13NotebookRunResponse\"o\n\x18\x43reateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x1b\n\x19\x43reateNotebookRunResponse\"o\n\x18UpdateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x1b\n\x19UpdateNotebookRunResponse\"8\n\x15GetNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x16GetNotebookRunResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteNotebookRunResponse2\x9e\t\n\x12NotebookRunService\x12\xd7\x01\n\x10ListNotebookRuns\x12N.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest\x1aO.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1alpha1/notebookruns\x12\xdd\x01\n\x11\x43reateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1alpha1/notebookruns:\x01*\x12\xd8\x01\n\x0eGetNotebookRun\x12L.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest\x1aM.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse\")\x82\xd3\xe4\x93\x02#\x12!/api/v1alpha1/notebookruns/{name}\x12\xf9\x01\n\x11UpdateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse\"A\x82\xd3\xe4\x93\x02;\x1a\x36/api/v1alpha1/notebookruns/{notebookrun.metadata.name}:\x01*\x12\xf6\x01\n\x11\x44\x65leteNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse\">\x82\xd3\xe4\x93\x02\x38*6/api/v1alpha1/notebookruns/{notebookrun.metadata.name}B7Z5github.com/metaprov/modelaapi/services/notebookrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=497,
)

_LISTNOTEBOOKRUNSREQUEST = _descriptor.Descriptor(
  name='ListNotebookRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=497,
)


_LISTNOTEBOOKRUNSRESPONSE = _descriptor.Descriptor(
  name='ListNotebookRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=615,
)


_NOTEBOOKRUNRESPONSE = _descriptor.Descriptor(
  name='NotebookRunResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=638,
)


_CREATENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='CreateNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=751,
)


_CREATENOTEBOOKRUNRESPONSE = _descriptor.Descriptor(
  name='CreateNotebookRunResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=780,
)


_UPDATENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='UpdateNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=893,
)


_UPDATENOTEBOOKRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateNotebookRunResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=922,
)


_GETNOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='GetNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=980,
)


_GETNOTEBOOKRUNRESPONSE = _descriptor.Descriptor(
  name='GetNotebookRunResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1105,
)


_DELETENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='DeleteNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1166,
)


_DELETENOTEBOOKRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteNotebookRunResponse',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1168,
  serialized_end=1195,
)

_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY.containing_type = _LISTNOTEBOOKRUNSREQUEST
_LISTNOTEBOOKRUNSREQUEST.fields_by_name['labels'].message_type = _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY
_LISTNOTEBOOKRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUNLIST
_CREATENOTEBOOKRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
_UPDATENOTEBOOKRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
_GETNOTEBOOKRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
DESCRIPTOR.message_types_by_name['ListNotebookRunsRequest'] = _LISTNOTEBOOKRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListNotebookRunsResponse'] = _LISTNOTEBOOKRUNSRESPONSE
DESCRIPTOR.message_types_by_name['NotebookRunResponse'] = _NOTEBOOKRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateNotebookRunRequest'] = _CREATENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['CreateNotebookRunResponse'] = _CREATENOTEBOOKRUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNotebookRunRequest'] = _UPDATENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotebookRunResponse'] = _UPDATENOTEBOOKRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetNotebookRunRequest'] = _GETNOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['GetNotebookRunResponse'] = _GETNOTEBOOKRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteNotebookRunRequest'] = _DELETENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotebookRunResponse'] = _DELETENOTEBOOKRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListNotebookRunsRequest = _reflection.GeneratedProtocolMessageType('ListNotebookRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest)
  })
_sym_db.RegisterMessage(ListNotebookRunsRequest)
_sym_db.RegisterMessage(ListNotebookRunsRequest.LabelsEntry)

ListNotebookRunsResponse = _reflection.GeneratedProtocolMessageType('ListNotebookRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse)
  })
_sym_db.RegisterMessage(ListNotebookRunsResponse)

NotebookRunResponse = _reflection.GeneratedProtocolMessageType('NotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunResponse)
  })
_sym_db.RegisterMessage(NotebookRunResponse)

CreateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRunRequest)

CreateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse)
  })
_sym_db.RegisterMessage(CreateNotebookRunResponse)

UpdateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRunRequest)

UpdateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookRunResponse)

GetNotebookRunRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest)
  })
_sym_db.RegisterMessage(GetNotebookRunRequest)

GetNotebookRunResponse = _reflection.GeneratedProtocolMessageType('GetNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse)
  })
_sym_db.RegisterMessage(GetNotebookRunResponse)

DeleteNotebookRunRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRunRequest)

DeleteNotebookRunResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookRunResponse)


DESCRIPTOR._options = None
_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._options = None

_NOTEBOOKRUNSERVICE = _descriptor.ServiceDescriptor(
  name='NotebookRunService',
  full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1198,
  serialized_end=2380,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListNotebookRuns',
    full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService.ListNotebookRuns',
    index=0,
    containing_service=None,
    input_type=_LISTNOTEBOOKRUNSREQUEST,
    output_type=_LISTNOTEBOOKRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/api/v1alpha1/notebookruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService.CreateNotebookRun',
    index=1,
    containing_service=None,
    input_type=_CREATENOTEBOOKRUNREQUEST,
    output_type=_CREATENOTEBOOKRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\032/api/v1alpha1/notebookruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService.GetNotebookRun',
    index=2,
    containing_service=None,
    input_type=_GETNOTEBOOKRUNREQUEST,
    output_type=_GETNOTEBOOKRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/api/v1alpha1/notebookruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService.UpdateNotebookRun',
    index=3,
    containing_service=None,
    input_type=_UPDATENOTEBOOKRUNREQUEST,
    output_type=_UPDATENOTEBOOKRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002;\0326/api/v1alpha1/notebookruns/{notebookrun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService.DeleteNotebookRun',
    index=4,
    containing_service=None,
    input_type=_DELETENOTEBOOKRUNREQUEST,
    output_type=_DELETENOTEBOOKRUNRESPONSE,
    serialized_options=b'\202\323\344\223\0028*6/api/v1alpha1/notebookruns/{notebookrun.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOTEBOOKRUNSERVICE)

DESCRIPTOR.services_by_name['NotebookRunService'] = _NOTEBOOKRUNSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/api/rbac/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='k8s.io/api/rbac/v1/generated.proto',
  package='k8s.io.api.rbac.v1',
  syntax='proto2',
  serialized_options=b'Z\002v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"k8s.io/api/rbac/v1/generated.proto\x12\x12k8s.io.api.rbac.v1\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"d\n\x0f\x41ggregationRule\x12Q\n\x14\x63lusterRoleSelectors\x18\x01 \x03(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\"\xbe\x01\n\x0b\x43lusterRole\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.rbac.v1.PolicyRule\x12<\n\x0f\x61ggregationRule\x18\x03 \x01(\x0b\x32#.k8s.io.api.rbac.v1.AggregationRule\"\xb5\x01\n\x12\x43lusterRoleBinding\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x08subjects\x18\x02 \x03(\x0b\x32\x1b.k8s.io.api.rbac.v1.Subject\x12,\n\x07roleRef\x18\x03 \x01(\x0b\x32\x1b.k8s.io.api.rbac.v1.RoleRef\"\x91\x01\n\x16\x43lusterRoleBindingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.k8s.io.api.rbac.v1.ClusterRoleBinding\"\x83\x01\n\x0f\x43lusterRoleList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.rbac.v1.ClusterRole\"q\n\nPolicyRule\x12\r\n\x05verbs\x18\x01 \x03(\t\x12\x11\n\tapiGroups\x18\x02 \x03(\t\x12\x11\n\tresources\x18\x03 \x03(\t\x12\x15\n\rresourceNames\x18\x04 \x03(\t\x12\x17\n\x0fnonResourceURLs\x18\x05 \x03(\t\"y\n\x04Role\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x05rules\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.rbac.v1.PolicyRule\"\xae\x01\n\x0bRoleBinding\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x08subjects\x18\x02 \x03(\x0b\x32\x1b.k8s.io.api.rbac.v1.Subject\x12,\n\x07roleRef\x18\x03 \x01(\x0b\x32\x1b.k8s.io.api.rbac.v1.RoleRef\"\x83\x01\n\x0fRoleBindingList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.rbac.v1.RoleBinding\"u\n\x08RoleList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.k8s.io.api.rbac.v1.Role\"7\n\x07RoleRef\x12\x10\n\x08\x61piGroup\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"J\n\x07Subject\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x10\n\x08\x61piGroup\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\tB\x04Z\x02v1'
  ,
  dependencies=[k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2.DESCRIPTOR,])




_AGGREGATIONRULE = _descriptor.Descriptor(
  name='AggregationRule',
  full_name='k8s.io.api.rbac.v1.AggregationRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusterRoleSelectors', full_name='k8s.io.api.rbac.v1.AggregationRule.clusterRoleSelectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=317,
)


_CLUSTERROLE = _descriptor.Descriptor(
  name='ClusterRole',
  full_name='k8s.io.api.rbac.v1.ClusterRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.ClusterRole.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='k8s.io.api.rbac.v1.ClusterRole.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregationRule', full_name='k8s.io.api.rbac.v1.ClusterRole.aggregationRule', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=510,
)


_CLUSTERROLEBINDING = _descriptor.Descriptor(
  name='ClusterRoleBinding',
  full_name='k8s.io.api.rbac.v1.ClusterRoleBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.ClusterRoleBinding.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subjects', full_name='k8s.io.api.rbac.v1.ClusterRoleBinding.subjects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roleRef', full_name='k8s.io.api.rbac.v1.ClusterRoleBinding.roleRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=694,
)


_CLUSTERROLEBINDINGLIST = _descriptor.Descriptor(
  name='ClusterRoleBindingList',
  full_name='k8s.io.api.rbac.v1.ClusterRoleBindingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.ClusterRoleBindingList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.rbac.v1.ClusterRoleBindingList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=842,
)


_CLUSTERROLELIST = _descriptor.Descriptor(
  name='ClusterRoleList',
  full_name='k8s.io.api.rbac.v1.ClusterRoleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.ClusterRoleList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.rbac.v1.ClusterRoleList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=976,
)


_POLICYRULE = _descriptor.Descriptor(
  name='PolicyRule',
  full_name='k8s.io.api.rbac.v1.PolicyRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='verbs', full_name='k8s.io.api.rbac.v1.PolicyRule.verbs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apiGroups', full_name='k8s.io.api.rbac.v1.PolicyRule.apiGroups', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='k8s.io.api.rbac.v1.PolicyRule.resources', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceNames', full_name='k8s.io.api.rbac.v1.PolicyRule.resourceNames', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonResourceURLs', full_name='k8s.io.api.rbac.v1.PolicyRule.nonResourceURLs', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1091,
)


_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='k8s.io.api.rbac.v1.Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.Role.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='k8s.io.api.rbac.v1.Role.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1214,
)


_ROLEBINDING = _descriptor.Descriptor(
  name='RoleBinding',
  full_name='k8s.io.api.rbac.v1.RoleBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.RoleBinding.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subjects', full_name='k8s.io.api.rbac.v1.RoleBinding.subjects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roleRef', full_name='k8s.io.api.rbac.v1.RoleBinding.roleRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1391,
)


_ROLEBINDINGLIST = _descriptor.Descriptor(
  name='RoleBindingList',
  full_name='k8s.io.api.rbac.v1.RoleBindingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.RoleBindingList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.rbac.v1.RoleBindingList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1525,
)


_ROLELIST = _descriptor.Descriptor(
  name='RoleList',
  full_name='k8s.io.api.rbac.v1.RoleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.rbac.v1.RoleList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.rbac.v1.RoleList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1644,
)


_ROLEREF = _descriptor.Descriptor(
  name='RoleRef',
  full_name='k8s.io.api.rbac.v1.RoleRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiGroup', full_name='k8s.io.api.rbac.v1.RoleRef.apiGroup', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.api.rbac.v1.RoleRef.kind', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.rbac.v1.RoleRef.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1701,
)


_SUBJECT = _descriptor.Descriptor(
  name='Subject',
  full_name='k8s.io.api.rbac.v1.Subject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.api.rbac.v1.Subject.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apiGroup', full_name='k8s.io.api.rbac.v1.Subject.apiGroup', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.rbac.v1.Subject.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='k8s.io.api.rbac.v1.Subject.namespace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1777,
)

_AGGREGATIONRULE.fields_by_name['clusterRoleSelectors'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LABELSELECTOR
_CLUSTERROLE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_CLUSTERROLE.fields_by_name['rules'].message_type = _POLICYRULE
_CLUSTERROLE.fields_by_name['aggregationRule'].message_type = _AGGREGATIONRULE
_CLUSTERROLEBINDING.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_CLUSTERROLEBINDING.fields_by_name['subjects'].message_type = _SUBJECT
_CLUSTERROLEBINDING.fields_by_name['roleRef'].message_type = _ROLEREF
_CLUSTERROLEBINDINGLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_CLUSTERROLEBINDINGLIST.fields_by_name['items'].message_type = _CLUSTERROLEBINDING
_CLUSTERROLELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_CLUSTERROLELIST.fields_by_name['items'].message_type = _CLUSTERROLE
_ROLE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_ROLE.fields_by_name['rules'].message_type = _POLICYRULE
_ROLEBINDING.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_ROLEBINDING.fields_by_name['subjects'].message_type = _SUBJECT
_ROLEBINDING.fields_by_name['roleRef'].message_type = _ROLEREF
_ROLEBINDINGLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_ROLEBINDINGLIST.fields_by_name['items'].message_type = _ROLEBINDING
_ROLELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_ROLELIST.fields_by_name['items'].message_type = _ROLE
DESCRIPTOR.message_types_by_name['AggregationRule'] = _AGGREGATIONRULE
DESCRIPTOR.message_types_by_name['ClusterRole'] = _CLUSTERROLE
DESCRIPTOR.message_types_by_name['ClusterRoleBinding'] = _CLUSTERROLEBINDING
DESCRIPTOR.message_types_by_name['ClusterRoleBindingList'] = _CLUSTERROLEBINDINGLIST
DESCRIPTOR.message_types_by_name['ClusterRoleList'] = _CLUSTERROLELIST
DESCRIPTOR.message_types_by_name['PolicyRule'] = _POLICYRULE
DESCRIPTOR.message_types_by_name['Role'] = _ROLE
DESCRIPTOR.message_types_by_name['RoleBinding'] = _ROLEBINDING
DESCRIPTOR.message_types_by_name['RoleBindingList'] = _ROLEBINDINGLIST
DESCRIPTOR.message_types_by_name['RoleList'] = _ROLELIST
DESCRIPTOR.message_types_by_name['RoleRef'] = _ROLEREF
DESCRIPTOR.message_types_by_name['Subject'] = _SUBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AggregationRule = _reflection.GeneratedProtocolMessageType('AggregationRule', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATIONRULE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.AggregationRule)
  })
_sym_db.RegisterMessage(AggregationRule)

ClusterRole = _reflection.GeneratedProtocolMessageType('ClusterRole', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRole)
  })
_sym_db.RegisterMessage(ClusterRole)

ClusterRoleBinding = _reflection.GeneratedProtocolMessageType('ClusterRoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLEBINDING,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleBinding)
  })
_sym_db.RegisterMessage(ClusterRoleBinding)

ClusterRoleBindingList = _reflection.GeneratedProtocolMessageType('ClusterRoleBindingList', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLEBINDINGLIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleBindingList)
  })
_sym_db.RegisterMessage(ClusterRoleBindingList)

ClusterRoleList = _reflection.GeneratedProtocolMessageType('ClusterRoleList', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERROLELIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.ClusterRoleList)
  })
_sym_db.RegisterMessage(ClusterRoleList)

PolicyRule = _reflection.GeneratedProtocolMessageType('PolicyRule', (_message.Message,), {
  'DESCRIPTOR' : _POLICYRULE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.PolicyRule)
  })
_sym_db.RegisterMessage(PolicyRule)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.Role)
  })
_sym_db.RegisterMessage(Role)

RoleBinding = _reflection.GeneratedProtocolMessageType('RoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDING,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleBinding)
  })
_sym_db.RegisterMessage(RoleBinding)

RoleBindingList = _reflection.GeneratedProtocolMessageType('RoleBindingList', (_message.Message,), {
  'DESCRIPTOR' : _ROLEBINDINGLIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleBindingList)
  })
_sym_db.RegisterMessage(RoleBindingList)

RoleList = _reflection.GeneratedProtocolMessageType('RoleList', (_message.Message,), {
  'DESCRIPTOR' : _ROLELIST,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleList)
  })
_sym_db.RegisterMessage(RoleList)

RoleRef = _reflection.GeneratedProtocolMessageType('RoleRef', (_message.Message,), {
  'DESCRIPTOR' : _ROLEREF,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.RoleRef)
  })
_sym_db.RegisterMessage(RoleRef)

Subject = _reflection.GeneratedProtocolMessageType('Subject', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECT,
  '__module__' : 'k8s.io.api.rbac.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.rbac.v1.Subject)
  })
_sym_db.RegisterMessage(Subject)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
